EasyGesture class

Inheritance
Available extensions

Constructors

EasyGesture({Key? key, void onTap()?, void onDoubleTap()?, void onLongPress()?, void onHorizontalSwipe(EasySwipeDirection)?, void onVerticalSwipe(EasySwipeDirection)?, double horizontalThreshold = 40, double verticalThreshold = 40, required Widget child})
const

Properties

alignBC → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignBL → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignBR → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignC → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignCL → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignCR → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignTC → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignTL → Align

Available on Widget, provided by the EasyWidgets extension

no setter
alignTR → Align

Available on Widget, provided by the EasyWidgets extension

no setter
child → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalThreshold → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDoubleTap → void Function()?
final
onHorizontalSwipe → void Function(EasySwipeDirection)?
final
onLongPress → void Function()?
final
onTap → void Function()?
final
onVerticalSwipe → void Function(EasySwipeDirection)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalThreshold → double
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
easyGesture({Key? key, void onTap()?, void onDoubleTap()?, void onLongPress()?, void onHorizontalSwipe(EasySwipeDirection)?, void onVerticalSwipe(EasySwipeDirection)?, double horizontalThreshold = 40, double verticalThreshold = 40}) → Widget

Available on Widget, provided by the EasyWidgets extension

Easilty handle normal and swipe Gesture
inkTap({void onTap()?, void onDoubleTap()?, void onLongPress()?, Color? backgroundColor, BorderRadius? borderRadius, Color? splashColor, Color? highlightColor, Color? hoverColor, EdgeInsets? padding, bool enableFeedback = true, double? feedbackDuration = 0.5}) → Widget

Available on Widget, provided by the EasyWidgets extension

Ink tap with splash effect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(void onTap()?) → GestureDetector

Available on Widget, provided by the EasyWidgets extension

onTap Gesture
padd(EdgeInsets insets) → Padding

Available on Widget, provided by the EasyWidgets extension

Padding
paddO({double left = 0, double right = 0, double top = 0, double bottom = 0}) → Padding

Available on Widget, provided by the EasyWidgets extension

Padding only
paddS({double horizontal = 0, double vertical = 0}) → Padding

Available on Widget, provided by the EasyWidgets extension

Padding Symmetric
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited